```
Made with Python3
(C) @FayasNoushad
Copyright permission under MIT License
License -> https://github.com/FayasNoushad/Pixeldrain/blob/main/LICENSE
```

---

## Installation

```
pip install Pixeldrain
```

---

## Usage

```py
import pixeldrain

upload = pixeldrain.upload_file(file)  # For upload file
file = pixeldrain.file(file_id)  # For get direct file
info = pixeldrain.info(file_id)  # For information about the file
thumbnail = pixeldrain.thumbnail(file_id, width, height)  # For thumbnail
```

---

## Credits

- [Fayas Noushad](https://github.com/FayasNoushad)
- [Pixeldrain API](https://pixeldrain.com/api)

---
